package org.bdware.sc;

import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.bdware.sc.db.CMTables;
import org.bdware.sc.db.KeyValueDBUtil;
import org.bdware.sc.db.StatusRecorder;
import org.bdware.sc.units.MultiContractMeta;

public class MultiContractRecorder extends StatusRecorder<MultiContractMeta> {
    static final String dbName = CMTables.UnitContracts.toString();
    static final String prefix = "Multi_C_Meta_";
    private static final Logger LOGGER = LogManager.getLogger(MultiContractRecorder.class);

    public MultiContractRecorder(String dir) {
        super(dir, dbName, prefix);
        for (MultiContractMeta meta : getStatus().values()) {
            try {
                meta.initQueue();
                int lastExeSeq =
                        Integer.parseInt(
                                KeyValueDBUtil.instance.getValue(
                                        CMTables.LastExeSeq.toString(), meta.getContractID()));
                meta.setLastExeSeq(lastExeSeq);
            } catch (Exception e) {
                e.printStackTrace();
            }
        }
    }

    public MultiContractMeta getMultiContractMeta(String idOrNameOrDOI) {
        if (idOrNameOrDOI == null) return null;
        ContractMeta meta = ContractManager.instance.statusRecorder.getContractMeta(idOrNameOrDOI);
        if (meta == null) return null;
        return getStatus().get(meta.id);
    }

    public MultiContractMeta createIfNotExist(String contractID) {
        MultiContractMeta ret = getMultiContractMeta(contractID);
        if (null == ret) {
            LOGGER.info("requests don't contain contract " + contractID);
            ret = new MultiContractMeta(contractID);
            updateValue(ret);
        }
        return ret;
    }
}
